@@ -42,6 +42,7 @@ private Q_SLOTS:
     void multiOutput();
     void clonesOutput();
     void configCanBeApplied();
+    void supportedFeatures();
     void cleanupTestCase();
 };
 
@@ -232,6 +233,18 @@ void testScreenConfig::configCanBeApplied()
     QVERIFY(!Config::canBeApplied(nulllConfig));
 }
 
+void testScreenConfig::supportedFeatures()
+{
+    ConfigPtr config = getConfig();
+
+    QVERIFY(config->supportedFeatures().testFlag(KScreen::Config::Feature::None));
+
+    config->setSupportedFeatures(KScreen::Config::Feature::Writable | KScreen::Config::Feature::PrimaryDisplay);
+
+    QVERIFY(config->supportedFeatures().testFlag(KScreen::Config::Feature::Writable));
+    QVERIFY(config->supportedFeatures().testFlag(KScreen::Config::Feature::PrimaryDisplay));
+}
+
 QTEST_MAIN(testScreenConfig)
 
 #include "testscreenconfig.moc"
